@@ -1,4 +1,3 @@
-# $Id: XML.pm,v 1.6 2006/08/22 19:19:45 jettero Exp $
 # vi:tw=0 syntax=perl:
 
 package Games::RolePlay::MapGen::Exporter::XML;
@@ -32,11 +31,11 @@ sub go {
 
     my $map = $this->genmap($opts);
     unless( $opts->{fname} eq "-retonly" ) {
-        open _MAP_OUT, ">$opts->{fname}" or die "ERROR: couldn't open $opts->{fname} for write: $!";
-        print _MAP_OUT "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n<!DOCTYPE MapGen SYSTEM \"MapGen.dtd\">\n";
-        print _MAP_OUT "<?xml-stylesheet type=\"text/xsl\" href=\"MapGen.xsl\"?>\n\n";
-        print _MAP_OUT "\n", $map;
-        close _MAP_OUT;
+        open my $out, ">$opts->{fname}" or die "ERROR: couldn't open $opts->{fname} for write: $!";
+        print $out "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n<!DOCTYPE MapGen SYSTEM \"MapGen.dtd\">\n";
+        print $out "<?xml-stylesheet type=\"text/xsl\" href=\"MapGen.xsl\"?>\n\n";
+        print $out "\n", $map;
+        close $out;
     }
 
     return $map;
@@ -69,8 +68,10 @@ sub genmap {
         unless( $k =~ m/^(?:_.+?|objs|plugins)$/ ) {
             my $v = $opts->{$k};
 
-            if( ref $v ) {
-                push @$options, $ah->( name=>$k, value=>join(" ", map { "$_: $v->{$_};" } keys %$v ));
+            if( my $t = ref $v ) {
+                next if $t ne "HASH"; # probably a r_cb => sub {} code ref from XMLImporter
+
+                push @$options, $ah->( name=>$k, value=>join(" ", map { "$_: $v->{$_};" } sort keys %$v ));
 
             } else {
                 push @$options, $ah->( name=>$k, value=>$v );
@@ -83,8 +84,12 @@ sub genmap {
         push @$groups, $ah->(
             name => $g->{name},
             type => $g->{type},
-            loc  => join(",", @{ $g->{loc}  }),
-            size => join("x", @{ $g->{size} }),
+            rectangle => [map {
+                $ah->(
+                    loc  => join(",", @{ $g->{loc}[$_]  }),
+                    size => join("x", @{ $g->{size}[$_] }),
+                )
+            } 0 .. $#{ $g->{loc} }],
         );
     }
     # }}}
@@ -97,6 +102,8 @@ sub genmap {
         for my $j (0 .. $jend) {
             my $tile = $opts->{_the_map}[$i][$j];
 
+            $opts->{t_cb}->() if exists $opts->{t_cb};
+
             if( my $t = $tile->{type} ) {
                 my $closures = [];
                 my $h = $ah->(
@@ -115,7 +122,7 @@ sub genmap {
                         my $door = $tile->{od}{$d};
 
                         push @$closures, $ah->( dir => $dir, type => "door", 
-                            (map { $_ => $door->{$_} ? "yes" : "no" } qw(locked stuck secret)),
+                            (map { $_ => $door->{$_} ? "yes" : "no" } qw(locked stuck secret open)),
 
                             (map { $_."_open_dir" => {n=>"north", e=>"east", s=>"south", w=>"west"}->{$door->{open_dir}{$_}} } qw(major minor)),
                         );
@@ -143,6 +150,13 @@ sub genmap {
         'map'      => { row => $map },
     );
 
+    ## DEBUG ## our $c; $c = 1 unless defined $c; $c ++;
+    ## DEBUG ## open my $out, ">lol.$c";
+    ## DEBUG ## use Data::Dumper; $Data::Dumper::Indent = $Data::Dumper::Sortkeys = 1;
+    ## DEBUG ## print $out Dumper(\%main), "\n";
+    ## DEBUG ## close $out;
+    ## DEBUG ## warn "eff dude (lol.$c)";
+
     return XMLout(\%main, 
         RootName => "MapGen",
         NoSort   => 1, # IxHash does this, please don't help me, kthx
